@@ -18,9 +18,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-int gnutls_cipher_set_priority( GNUTLS_STATE state, GNUTLS_LIST);
-int gnutls_kx_set_priority( GNUTLS_STATE state, GNUTLS_LIST); 
-int gnutls_mac_set_priority( GNUTLS_STATE state, GNUTLS_LIST);
-int gnutls_compression_set_priority( GNUTLS_STATE state, GNUTLS_LIST);
-int gnutls_protocol_set_priority( GNUTLS_STATE state, GNUTLS_LIST);
-int gnutls_cert_type_set_priority( GNUTLS_STATE state, GNUTLS_LIST);
+int gnutls_cipher_set_priority( gnutls_session session, gnutls_list);
+int gnutls_kx_set_priority( gnutls_session session, gnutls_list); 
+int gnutls_mac_set_priority( gnutls_session session, gnutls_list);
+int gnutls_compression_set_priority( gnutls_session session, gnutls_list);
+int gnutls_protocol_set_priority( gnutls_session session, gnutls_list);
+int gnutls_certificate_type_set_priority( gnutls_session session, gnutls_list);
