@@ -588,12 +588,12 @@ static GNUTLS_X509_SUBJECT_ALT_NAME _find_type( char* str_type) {
   * This is specified in X509v3 Certificate Extensions. 
   * GNUTLS will return the Alternative name, or a negative
   * error code.
-  * Returns GNUTLS_E_INVALID_REQUEST if ret_size is not enough to hold the alternative name,
-  * or the type of alternative name if everything was ok. The type is one of the
-  * enumerated GNUTLS_X509_SUBJECT_ALT_NAME.
+  * Returns GNUTLS_E_INVALID_REQUEST if ret_size is not enough to hold the alternative 
+  * name, or the type of alternative name if everything was ok. The type is 
+  * one of the enumerated GNUTLS_X509_SUBJECT_ALT_NAME.
   *
-  * If the certificate does not have an Alternative name with the specified sequence number
-  * then returns GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
+  * If the certificate does not have an Alternative name with the specified 
+  * sequence number then returns GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
   *
   **/
 int gnutls_x509_extract_certificate_subject_alt_name(const gnutls_datum * cert, int seq, char *ret, int *ret_size)
@@ -814,34 +814,34 @@ int gnutls_x509_extract_certificate_version(const gnutls_datum * cert)
 
 /*-
   * _gnutls_x509_cert_verify_peers - This function returns the peer's certificate status
-  * @state: is a gnutls state
+  * @session: is a gnutls session
   *
   * This function will try to verify the peer's certificate and return it's status (TRUSTED, EXPIRED etc.). 
-  * The return value (status) should be one of the CertificateStatus enumerated elements.
+  * The return value (status) should be one of the gnutls_certificate_status enumerated elements.
   * However you must also check the peer's name in order to check if the verified certificate belongs to the 
   * actual peer. Returns a negative error code in case of an error, or GNUTLS_E_NO_CERTIFICATE_FOUND if no certificate was sent.
   *
   -*/
-int _gnutls_x509_cert_verify_peers(GNUTLS_STATE state)
+int _gnutls_x509_cert_verify_peers(gnutls_session session)
 {
 	CERTIFICATE_AUTH_INFO info;
 	const GNUTLS_CERTIFICATE_CREDENTIALS cred;
-	CertificateStatus verify;
+	gnutls_certificate_status verify;
 	gnutls_cert *peer_certificate_list;
 	int peer_certificate_list_size, i, x, ret;
 
 	CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, GNUTLS_E_INVALID_REQUEST);
 
-	info = _gnutls_get_auth_info(state);
+	info = _gnutls_get_auth_info(session);
 	if (info == NULL) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 	
-	cred = _gnutls_get_cred(state->gnutls_key, GNUTLS_CRD_CERTIFICATE, NULL);
+	cred = _gnutls_get_cred(session->gnutls_key, GNUTLS_CRD_CERTIFICATE, NULL);
 	if (cred == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INSUFICIENT_CRED;
+		return GNUTLS_E_INSUFICIENT_CREDENTIALS;
 	}
 
 	if (info->raw_certificate_list == NULL || info->ncerts == 0)
@@ -904,14 +904,17 @@ int _gnutls_x509_cert_verify_peers(GNUTLS_STATE state)
   * @CRL_list_length: not used
   *
   * This function will try to verify the given certificate list and return it's status (TRUSTED, EXPIRED etc.). 
-  * The return value (status) should be one or more of the CertificateStatus 
+  * The return value (status) should be one or more of the gnutls_certificate_status 
   * enumerated elements bitwise or'd. Note that expiration and activation dates are not checked 
   * by this function, you should check them using the appropriate functions.
   *
+  * This function understands the basicConstraints (2 5 29 19) PKIX extension.
+  * This means that only a certificate authority can sign a certificate.
+  *
   * However you must also check the peer's name in order to check if the verified certificate belongs to the 
   * actual peer. 
   *
-  * The return value (status) should be one or more of the CertificateStatus 
+  * The return value (status) should be one or more of the gnutls_certificate_status 
   * enumerated elements bitwise or'd.
   *
   * GNUTLS_CERT_NOT_TRUSTED\: the peer's certificate is not trusted.
@@ -931,7 +934,7 @@ int _gnutls_x509_cert_verify_peers(GNUTLS_STATE state)
   **/
 int gnutls_x509_verify_certificate( const gnutls_datum* cert_list, int cert_list_length, const gnutls_datum * CA_list, int CA_list_length, const gnutls_datum* CRL_list, int CRL_list_length)
 {
-	CertificateStatus verify;
+	gnutls_certificate_status verify;
 	gnutls_cert *peer_certificate_list;
 	gnutls_cert *ca_certificate_list;
 	int peer_certificate_list_size, i, x, ret, ca_certificate_list_size;
@@ -1207,11 +1210,16 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 	gnutls_datum tmp;
 	int ret, count;
 
-	ptr = input_cert;
-	siz = input_cert_size;
+	if ( (ptr = strstr( input_cert, PEM_PKCS7_SEP)) != NULL) 
+	{
+		siz = strlen( ptr);
 
-	if (strstr( input_cert, "-----BEGIN PKCS7")!=NULL) {
-		siz2 = _gnutls_fbase64_decode(ptr, siz, &b64);
+		siz2 = _gnutls_fbase64_decode( NULL, ptr, siz, &b64);
+
+		if (siz2 < 0) {
+			gnutls_assert();
+			return GNUTLS_E_PARSING_ERROR;
+		}
 
 		ret = parse_pkcs7_cert_mem( cert_list, ncerts, b64,
 			siz2);
@@ -1221,20 +1229,29 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 		return ret;
 	}
 
+	/* move to the certificate
+	 */
+	ptr = strstr( input_cert, PEM_CERT_SEP);
+	if (ptr == NULL) ptr = strstr( input_cert, PEM_CERT_SEP2);
+
+	if (ptr == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_PARSING_ERROR;
+	}
+	siz = strlen( ptr);
+
 	i = *ncerts + 1;
 	count = 0;
 
 	do {
-		siz2 = _gnutls_fbase64_decode(ptr, siz, &b64);
-		siz -= siz2;	/* FIXME: this is not enough
-				 */
+		siz2 = _gnutls_fbase64_decode(NULL, ptr, siz, &b64);
+		siz -= siz2;
 
 		if (siz2 < 0) {
 			gnutls_assert();
 			return GNUTLS_E_PARSING_ERROR;
 		}
 
-
 		*cert_list =
 		    (gnutls_cert *) gnutls_realloc( *cert_list,
 						   i *
@@ -1259,14 +1276,18 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 		}
 		gnutls_free(b64);
 
-		/* now we move ptr after the pem header */
+		/* now we move ptr after the pem header 
+		 */
+		ptr++;
+		/* find the next certificate (if any)
+		 */
 		ptr = strstr(ptr, PEM_CERT_SEP);
-		if (ptr!=NULL)
-			ptr++;
+		if (ptr == NULL) ptr = strstr( input_cert, PEM_CERT_SEP2);
 
 		i++;
 		count++;
-	} while ((ptr = strstr(ptr, PEM_CERT_SEP)) != NULL);
+
+	} while ( ptr != NULL);
 
 	*ncerts = i - 1;
 
@@ -1275,10 +1296,10 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 
 
 
-/* Reads a base64 encoded certificate from memory
+/* Reads a DER or PEM certificate from memory
  */
 static int read_cert_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *cert, int cert_size, 
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 	int ret;
 
@@ -1319,7 +1340,7 @@ static int read_cert_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *cert, i
  * This is to be called once.
  */
 static int read_ca_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *ca, int ca_size,
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 
 	if (type==GNUTLS_X509_FMT_DER)
@@ -1376,12 +1397,12 @@ int _gnutls_der_check_if_rsa_key(const gnutls_datum * key_struct)
  * type indicates the certificate format.
  */
 static int read_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *key, int key_size, 
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 	int ret;
 	opaque *b64 = NULL;
 	gnutls_datum tmp;
-	PKAlgorithm pk;
+	gnutls_pk_algorithm pk;
 
 	/* allocate space for the pkey list
 	 */
@@ -1413,12 +1434,25 @@ static int read_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *key, int
 		/* If we find the "DSA PRIVATE" string in the
 		 * pem encoded certificate then it's a DSA key.
 		 */
-		if (strstr( key, "DSA PRIVATE")!=NULL) 
+		if (strstr( key, "DSA PRIVATE")!=NULL) {
 			pk = GNUTLS_PK_DSA;
-		else
+			key = strstr( key, PEM_KEY_DSA_SEP);
+			if (key == NULL) {
+				gnutls_assert();
+				return GNUTLS_E_PARSING_ERROR;
+			}			key_size = strlen( key);
+		} else {
 			pk = GNUTLS_PK_RSA;
+			key = strstr( key, PEM_KEY_RSA_SEP);
+			if (key == NULL) {
+				gnutls_assert();
+				return GNUTLS_E_PARSING_ERROR;
+			}
+			key_size = strlen( key);
+		}
+			
 
-		ret = _gnutls_fbase64_decode(key, key_size, &b64);
+		ret = _gnutls_fbase64_decode( NULL, key, key_size, &b64);
 
 		if (ret < 0) {
 			gnutls_assert();
@@ -1466,7 +1500,7 @@ static int read_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *key, int
 /* Reads a certificate file
  */
 static int read_cert_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *certfile,
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 	int siz;
 	char x[MAX_FILE_SIZE];
@@ -1489,7 +1523,7 @@ static int read_cert_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *certfi
  * authorities). This is to be called once.
  */
 static int read_ca_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *cafile, 
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 	int siz;
 	char x[MAX_FILE_SIZE];
@@ -1514,7 +1548,7 @@ static int read_ca_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *cafile,
  * stores it).
  */
 static int read_key_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *keyfile,
-	GNUTLS_X509_CertificateFmt type)
+	gnutls_x509_certificate_format type)
 {
 	int siz;
 	char x[MAX_FILE_SIZE];
@@ -1532,6 +1566,52 @@ static int read_key_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *keyfile
 	return read_key_mem( res, x, siz, type);
 }
 
+/**
+  * gnutls_certificate_set_x509_key_mem - Used to set keys in a GNUTLS_CERTIFICATE_CREDENTIALS structure
+  * @res: is an &GNUTLS_CERTIFICATE_CREDENTIALS structure.
+  * @CERT: contains a certificate list (path) for the specified private key
+  * @KEY: is the private key
+  * @type: is PEM or DER
+  *
+  * This function sets a certificate/private key pair in the 
+  * GNUTLS_CERTIFICATE_CREDENTIALS structure. This function may be called
+  * more than once (in case multiple keys/certificates exist for the
+  * server).
+  *
+  * Currently are supported: RSA PKCS-1 encoded private keys, 
+  * DSA private keys.
+  *
+  * DSA private keys are encoded the OpenSSL way, which is an ASN.1
+  * DER sequence of 6 INTEGERs - version, p, q, g, pub, priv.
+  *
+  * Note that the keyUsage (2 5 29 15) PKIX extension in X.509 certificates 
+  * is supported. This means that certificates intended for signing cannot
+  * be used for ciphersuites that require encryption.
+  *
+  * If the certificate and the private key are given in PEM encoding
+  * then the strings that hold their values must be null terminated.
+  *
+  **/
+int gnutls_certificate_set_x509_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const gnutls_datum* CERT,
+			   const gnutls_datum* KEY, gnutls_x509_certificate_format type)
+{
+	int ret;
+
+	/* this should be first 
+	 */
+	if ((ret = read_key_mem( res, KEY->data, KEY->size, type)) < 0)
+		return ret;
+
+	if ((ret = read_cert_mem( res, CERT->data, CERT->size, type)) < 0)
+		return ret;
+
+	if ((ret=_gnutls_check_key_cert_match( res)) < 0) {
+		gnutls_assert();
+		return ret;
+	}
+
+	return 0;
+}
 
 /**
   * gnutls_certificate_set_x509_key_file - Used to set keys in a GNUTLS_CERTIFICATE_CREDENTIALS structure
@@ -1551,7 +1631,7 @@ static int read_key_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *keyfile
   *
   **/
 int gnutls_certificate_set_x509_key_file(GNUTLS_CERTIFICATE_CREDENTIALS res, const char *CERTFILE,
-			   const char *KEYFILE, GNUTLS_X509_CertificateFmt type)
+			   const char *KEYFILE, gnutls_x509_certificate_format type)
 {
 	int ret;
 
@@ -1636,7 +1716,7 @@ opaque *pdata;
   *
   **/
 int gnutls_certificate_set_x509_trust_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, 
-	const gnutls_datum *CA, GNUTLS_X509_CertificateFmt type)
+	const gnutls_datum *CA, gnutls_x509_certificate_format type)
 {
 	int ret, ret2;
 
@@ -1661,7 +1741,7 @@ int gnutls_certificate_set_x509_trust_mem(GNUTLS_CERTIFICATE_CREDENTIALS res,
   *
   **/
 int gnutls_certificate_set_x509_trust_file(GNUTLS_CERTIFICATE_CREDENTIALS res, 
-		const char *CAFILE, GNUTLS_X509_CertificateFmt type)
+		const char *CAFILE, gnutls_x509_certificate_format type)
 {
 	int ret, ret2;
 
@@ -1674,49 +1754,6 @@ int gnutls_certificate_set_x509_trust_file(GNUTLS_CERTIFICATE_CREDENTIALS res,
 	return ret;
 }
 
-
-/**
-  * gnutls_certificate_set_x509_key_mem - Used to set keys in a GNUTLS_CERTIFICATE_CREDENTIALS structure
-  * @res: is an &GNUTLS_CERTIFICATE_CREDENTIALS structure.
-  * @CERT: contains a certificate list (path) for the specified private key
-  * @KEY: is the private key
-  * @type: is PEM or DER
-  *
-  * This function sets a certificate/private key pair in the 
-  * GNUTLS_CERTIFICATE_CREDENTIALS structure. This function may be called
-  * more than once (in case multiple keys/certificates exist for the
-  * server).
-  *
-  * Currently are supported: RSA PKCS-1 encoded private keys, 
-  * DSA private keys.
-  *
-  * DSA private keys are encoded the OpenSSL way, which is an ASN.1
-  * DER sequence of 6 INTEGERs - version, p, q, g, pub, priv.
-  *
-  **/
-int gnutls_certificate_set_x509_key_mem(GNUTLS_CERTIFICATE_CREDENTIALS res, const gnutls_datum* CERT,
-			   const gnutls_datum* KEY, GNUTLS_X509_CertificateFmt type)
-{
-	int ret;
-
-	/* this should be first 
-	 */
-	if ((ret = read_key_mem( res, KEY->data, KEY->size, type)) < 0)
-		return ret;
-
-	if ((ret = read_cert_mem( res, CERT->data, CERT->size, type)) < 0)
-		return ret;
-
-	if ((ret=_gnutls_check_key_cert_match( res)) < 0) {
-		gnutls_assert();
-		return ret;
-	}
-
-	return 0;
-}
-
-
-
 static int _read_rsa_params(opaque * der, int dersize, GNUTLS_MPI * params)
 {
 	opaque str[MAX_PARAMETER_SIZE];
@@ -2135,11 +2172,11 @@ int _gnutls_x509_cert2gnutls_cert(gnutls_cert * gCert, gnutls_datum derCert,
 
 }
 
-/* Returns 0 if it's ok to use the KXAlgorithm with this cert
+/* Returns 0 if it's ok to use the gnutls_kx_algorithm with this cert
  * (using KeyUsage field). 
  */
 int _gnutls_check_x509_key_usage(const gnutls_cert * cert,
-				    KXAlgorithm alg)
+				    gnutls_kx_algorithm alg)
 {
 	if (_gnutls_map_kx_get_cred(alg) == GNUTLS_CRD_CERTIFICATE) {
 		switch (alg) {
@@ -2358,7 +2395,7 @@ int gnutls_x509_pkcs7_extract_certificate(const gnutls_datum * pkcs7_struct, int
   * For DSA the bits returned are of the public
   * exponent.
   *
-  * Returns a member of the GNUTLS_PKAlgorithm enumeration on success,
+  * Returns a member of the gnutls_pk_algorithm enumeration on success,
   * or a negative value on error.
   *
   **/
