@@ -32,11 +32,11 @@
 #include "auth_srp.h"
 #include <gnutls_str.h>
 
-int gen_srp_server_kx2(GNUTLS_STATE, opaque **);
-int gen_srp_client_kx0(GNUTLS_STATE, opaque **);
+int gen_srp_server_kx2(gnutls_session, opaque **);
+int gen_srp_client_kx0(gnutls_session, opaque **);
 
-int proc_srp_server_kx2(GNUTLS_STATE, opaque *, int);
-int proc_srp_client_kx0(GNUTLS_STATE, opaque *, int);
+int proc_srp_server_kx2(gnutls_session, opaque *, int);
+int proc_srp_client_kx0(gnutls_session, opaque *, int);
 
 const MOD_AUTH_STRUCT srp_auth_struct = {
 	"SRP",
@@ -72,13 +72,12 @@ const MOD_AUTH_STRUCT srp_auth_struct = {
 /* Send the first key exchange message ( g, n, s) and append the verifier algorithm number 
  * Data is allocated by the caller, and should have data_size size.
  */
-int gen_srp_server_hello(GNUTLS_STATE state, opaque * data, int data_size)
+int gen_srp_server_hello(gnutls_session state, opaque * data, int data_size)
 {
 	size_t n_g, n_n, n_s;
 	size_t ret;
 	uint8 *data_n, *data_s;
 	uint8 *data_g, *username;
-	uint8 pwd_algo;
 	GNUTLS_SRP_PWD_ENTRY *pwd_entry;
 	int err;
 	SRP_SERVER_AUTH_INFO info;
@@ -105,8 +104,6 @@ int gen_srp_server_hello(GNUTLS_STATE state, opaque * data, int data_size)
 		        return GNUTLS_E_PWD_ERROR;
 	}
 
-	pwd_algo = (uint8) pwd_entry->algorithm;
-
 	if (_gnutls_mpi_print( NULL, &n_g, pwd_entry->g)!=0) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_PRINT_FAILED;
@@ -130,21 +127,15 @@ int gen_srp_server_hello(GNUTLS_STATE state, opaque * data, int data_size)
 	_gnutls_mpi_set(N, pwd_entry->n);
 	_gnutls_mpi_set(V, pwd_entry->v);
 
-	if (data_size < n_n + n_g + pwd_entry->salt_size + 6 + 1) {
+	if (data_size < n_n + n_g + pwd_entry->salt_size + 6) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
 	data_g = data; 
 
-	/* firstly copy the algorithm used to generate the verifier 
-	 */
-	data_g[0] = pwd_algo;
-
 	/* copy G (generator) to data */
 
-	data_g++;
-	
 	if(_gnutls_mpi_print( &data_g[2], &n_g, G)!=0) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_PRINT_FAILED;
@@ -176,7 +167,7 @@ int gen_srp_server_hello(GNUTLS_STATE state, opaque * data, int data_size)
 }
 
 /* send the second key exchange message  */
-int gen_srp_server_kx2(GNUTLS_STATE state, opaque ** data)
+int gen_srp_server_kx2(gnutls_session state, opaque ** data)
 {
 	int ret;
 	size_t n_b;
@@ -238,7 +229,7 @@ int gen_srp_server_kx2(GNUTLS_STATE state, opaque ** data)
 
 
 /* return A = g^a % N */
-int gen_srp_client_kx0(GNUTLS_STATE state, opaque ** data)
+int gen_srp_client_kx0(gnutls_session state, opaque ** data)
 {
 	size_t n_a;
 	uint8 *data_a;
@@ -292,14 +283,13 @@ int gen_srp_client_kx0(GNUTLS_STATE state, opaque ** data)
 }
 
 /* receive the first key exchange message ( g, n, s) */
-int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size)
+int proc_srp_server_hello(gnutls_session state, const opaque * data, int data_size)
 {
 	uint16 n_s, n_g, n_n;
 	size_t _n_s, _n_g, _n_n;
 	const uint8 *data_n;
 	const uint8 *data_g;
 	const uint8 *data_s;
-	uint8 pwd_algo;
 	int i, ret;
 	opaque hd[SRP_MAX_HASH_SIZE];
 	char *username;
@@ -321,9 +311,6 @@ int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size
 /* read the algorithm used to generate V */
 	
 	i = 0;
-	DECR_LEN( data_size, 1);
-	pwd_algo = data[0];
-	i++;
 
 	DECR_LEN( data_size, 2);
 	n_g = _gnutls_read_uint16( &data[i]);
@@ -370,7 +357,7 @@ int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size
 	/* generate x = SHA(s | SHA(U | ":" | p))
 	 * (or the equivalent using bcrypt)
 	 */
-	if ( ( ret =_gnutls_calc_srp_x( username, password, (opaque*)data_s, n_s, pwd_algo, &_n_g, hd)) < 0) {
+	if ( ( ret =_gnutls_calc_srp_x( username, password, (opaque*)data_s, n_s, &_n_g, hd)) < 0) {
 		gnutls_assert();
 		return ret;
 	}
@@ -384,7 +371,7 @@ int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size
 }
 
 /* just read A and put it to state */
-int proc_srp_client_kx0(GNUTLS_STATE state, opaque * data, int data_size)
+int proc_srp_client_kx0(gnutls_session state, opaque * data, int data_size)
 {
 	size_t _n_A;
 
@@ -401,7 +388,7 @@ int proc_srp_client_kx0(GNUTLS_STATE state, opaque * data, int data_size)
 }
 
 
-int proc_srp_server_kx2(GNUTLS_STATE state, opaque * data, int data_size)
+int proc_srp_server_kx2(gnutls_session state, opaque * data, int data_size)
 {
 	size_t _n_B;
 	int ret;
