@@ -39,7 +39,7 @@
  * string(username):base64(v):base64(salt):int(index)
  */
 static int pwd_put_values( GNUTLS_SRP_PWD_ENTRY *entry, char *str, int str_size) {
-char * p, *p2;
+char * p;
 int len, ret;
 opaque *verifier;
 size_t verifier_size;
@@ -90,20 +90,6 @@ int indx;
 	*p='\0';
 	p++;
 
-	if ( (p2 = index(p, '$')) == NULL) {
-		entry->algorithm = SRPSHA1_CRYPT;
-	} else {
-		p++;
-		entry->algorithm = atoi(p);
-		p2 = index(p, '$'); /* find the last $ */
-		if (p2==NULL) {
-			gnutls_assert();
-			gnutls_free(entry->salt);
-			return GNUTLS_E_PARSING_ERROR;
-		}
-		p = p2+1;
-	}
-
 	len = strlen(p);
 	ret = _gnutls_sbase64_decode( p, len, &verifier);
 	if (ret <= 0) {
@@ -242,7 +228,7 @@ static int pwd_read_conf( const char* pconf_file, GNUTLS_SRP_PWD_ENTRY* entry, i
 }
 
 
-GNUTLS_SRP_PWD_ENTRY *_gnutls_srp_pwd_read_entry( GNUTLS_STATE state, char* username, int *err) {
+GNUTLS_SRP_PWD_ENTRY *_gnutls_srp_pwd_read_entry( gnutls_session state, char* username, int *err) {
 	const GNUTLS_SRP_SERVER_CREDENTIALS cred;
 	FILE * fd;
 	char line[2*1024];
@@ -273,8 +259,8 @@ GNUTLS_SRP_PWD_ENTRY *_gnutls_srp_pwd_read_entry( GNUTLS_STATE state, char* user
 	}
 	
 	/* use the callback to select a password file */
-	if (state->gnutls_internals.server_srp_callback!=NULL) {
-		pwd_index = state->gnutls_internals.server_srp_callback(
+	if (state->internals.server_srp_callback!=NULL) {
+		pwd_index = state->internals.server_srp_callback(
 			state, cred->password_file, cred->password_conf_file,
 				cred->password_files);
 
@@ -365,8 +351,6 @@ GNUTLS_SRP_PWD_ENTRY* _gnutls_randomize_pwd_entry() {
 		return NULL;
 	}
 	
-	pwd_entry->algorithm = 0;
-
 	return pwd_entry;
 
 }
