@@ -1092,6 +1092,9 @@ leave:
  * at all. Then we don't check the signatures because it makes no sense.
  *
  * The return value is one of the CertificateStatus entries.
+ *
+ * NOTE: this function does not verify using any "web of trust". You
+ * may use GnuPG for that purpose, or any other external PGP application.
  **/
 int
 gnutls_openpgp_verify_key( const char *trustdb,
@@ -2058,10 +2061,12 @@ gnutls_openpgp_key_to_xml( const gnutls_datum *cert,
 {
     return GNUTLS_E_UNIMPLEMENTED_FEATURE;   
 }
+
+int
+gnutls_openpgp_extract_key_id( const gnutls_datum *cert, unsigned char keyid[8] )
+{
+	return GNUTLS_E_UNIMPLEMENTED_FEATURE;
+}
+
 #endif /* HAVE_LIBOPENCDK */
 
-
-
-
-
-
