@@ -27,7 +27,6 @@
 
 #include <gnutls_srp.h>
 #include <auth_srp_passwd.h>
-#include <crypt_bcrypt.h>
 #include <gnutls_mpi.h>
 #include "debug.h"
 
@@ -258,18 +257,11 @@ int _gnutls_calc_srp_sha(char *username, char *password, opaque * salt,
 }
 
 int _gnutls_calc_srp_x(char *username, char *password, opaque * salt,
-			 size_t salt_size, uint8 crypt_algo, size_t *size, void* digest)
+			 size_t salt_size, size_t *size, void* digest)
 {
 
-	switch (crypt_algo) {
-	case SRPSHA1_CRYPT:
-		return _gnutls_calc_srp_sha(username, password, salt,
+	return _gnutls_calc_srp_sha(username, password, salt,
 					    salt_size, size, digest);
-	case BLOWFISH_CRYPT:
-		return _gnutls_calc_srp_bcrypt(username, password, salt, salt_size,
-					       size, digest);
-	}
-	return -1;
 }
 
 
@@ -312,28 +304,28 @@ GNUTLS_MPI _gnutls_calc_srp_S2(GNUTLS_MPI B, GNUTLS_MPI g, GNUTLS_MPI x, GNUTLS_
 }
 
 /**
-  * gnutls_srp_free_server_cred - Used to free an allocated GNUTLS_SRP_CLIENT_CREDENTIALS structure
+  * gnutls_srp_free_server_credentials - Used to free an allocated GNUTLS_SRP_CLIENT_CREDENTIALS structure
   * @sc: is an &GNUTLS_SRP_CLIENT_CREDENTIALS structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate)
   * the structure.
   **/
-void gnutls_srp_free_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS sc) {
+void gnutls_srp_free_client_credentials( GNUTLS_SRP_CLIENT_CREDENTIALS sc) {
 	gnutls_free( sc->username);
 	gnutls_free( sc->password);
 	gnutls_free( sc);
 }
 
 /**
-  * gnutls_srp_allocate_server_cred - Used to allocate an GNUTLS_SRP_SERVER_CREDENTIALS structure
+  * gnutls_srp_allocate_server_credentials - Used to allocate an GNUTLS_SRP_SERVER_CREDENTIALS structure
   * @sc: is a pointer to an &GNUTLS_SRP_SERVER_CREDENTIALS structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate
   * the structure.
   **/
-int gnutls_srp_allocate_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS *sc) {
+int gnutls_srp_allocate_client_credentials( GNUTLS_SRP_CLIENT_CREDENTIALS *sc) {
 	*sc = gnutls_calloc( 1, sizeof(SRP_CLIENT_CREDENTIALS_INT));
   
 	if (*sc==NULL) return GNUTLS_E_MEMORY_ERROR;
@@ -342,13 +334,13 @@ int gnutls_srp_allocate_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS *sc) {
 }
 
 /**
-  * gnutls_srp_set_client_cred - Used to set the username/password, in a GNUTLS_SRP_CLIENT_CREDENTIALS structure
+  * gnutls_srp_set_client_credentials - Used to set the username/password, in a GNUTLS_SRP_CLIENT_CREDENTIALS structure
   * @res: is an &GNUTLS_SRP_CLIENT_CREDENTIALS structure.
   * @username: is the user's userid
   * @password: is the user's password
   *
   **/
-int gnutls_srp_set_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS res, char *username, char * password) {
+int gnutls_srp_set_client_credentials( GNUTLS_SRP_CLIENT_CREDENTIALS res, char *username, char * password) {
 
 	if (username==NULL || password == NULL) {
 		gnutls_assert();
@@ -368,14 +360,14 @@ int gnutls_srp_set_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS res, char *usernam
 }
 
 /**
-  * gnutls_srp_free_server_cred - Used to free an allocated GNUTLS_SRP_SERVER_CREDENTIALS structure
+  * gnutls_srp_free_server_credentials - Used to free an allocated GNUTLS_SRP_SERVER_CREDENTIALS structure
   * @sc: is an &GNUTLS_SRP_SERVER_CREDENTIALS structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate)
   * the structure.
   **/
-void gnutls_srp_free_server_cred( GNUTLS_SRP_SERVER_CREDENTIALS sc) {
+void gnutls_srp_free_server_credentials( GNUTLS_SRP_SERVER_CREDENTIALS sc) {
 int i;
 	for (i=0;i<sc->password_files;i++) {
 		gnutls_free( sc->password_file[i]);
@@ -388,14 +380,14 @@ int i;
 }
 
 /**
-  * gnutls_srp_allocate_server_cred - Used to allocate an GNUTLS_SRP_SERVER_CREDENTIALS structure
+  * gnutls_srp_allocate_server_credentials - Used to allocate an GNUTLS_SRP_SERVER_CREDENTIALS structure
   * @sc: is a pointer to an &GNUTLS_SRP_SERVER_CREDENTIALS structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate
   * the structure.
   **/
-int gnutls_srp_allocate_server_cred( GNUTLS_SRP_SERVER_CREDENTIALS *sc) {
+int gnutls_srp_allocate_server_credentials( GNUTLS_SRP_SERVER_CREDENTIALS *sc) {
 	*sc = gnutls_calloc( 1, sizeof(SRP_SERVER_CREDENTIALS_INT));
 	
 	if (*sc==NULL) return GNUTLS_E_MEMORY_ERROR;
@@ -415,13 +407,13 @@ FILE* fd;
 }
 
 /**
-  * gnutls_srp_set_server_cred_file - Used to set the password files, in a GNUTLS_SRP_SERVER_CREDENTIALS structure
+  * gnutls_srp_set_server_credentials_file - Used to set the password files, in a GNUTLS_SRP_SERVER_CREDENTIALS structure
   * @res: is an &GNUTLS_SRP_SERVER_CREDENTIALS structure.
   * @password_file: is the SRP password file (tpasswd)
   * @password_conf_file: is the SRP password conf file (tpasswd.conf)
   *
   **/
-int gnutls_srp_set_server_cred_file( GNUTLS_SRP_SERVER_CREDENTIALS res, char *password_file, char * password_conf_file) {
+int gnutls_srp_set_server_credentials_file( GNUTLS_SRP_SERVER_CREDENTIALS res, char *password_file, char * password_conf_file) {
 int i;
 	
 	if (password_file==NULL || password_conf_file==NULL) {
@@ -474,11 +466,11 @@ int i;
 
 /**
   * gnutls_srp_server_set_select_function - Used to set a callback to assist in selecting the proper password file
-  * @state: is a &GNUTLS_STATE structure.
+  * @session: is a &gnutls_session structure.
   * @func: is the callback function
   *
   * The callback's function form is:
-  * int (*callback)(GNUTLS_STATE, const char** pfiles, const char** pconffiles, int npfiles);
+  * int (*callback)(gnutls_session, const char** pfiles, const char** pconffiles, int npfiles);
   *
   * 'pfiles' contains 'npfiles' char* structures which hold
   * the password file name. 'pconffiles' contain the corresponding
@@ -498,32 +490,62 @@ int i;
   * choosen by the server. -1 indicates an error.
   *
   **/
-void gnutls_srp_server_set_select_function(GNUTLS_STATE state,
+void gnutls_srp_server_set_select_function(gnutls_session session,
 					     srp_server_select_func
 					     * func)
 {
-	state->gnutls_internals.server_srp_callback = func;
+	session->internals.server_srp_callback = func;
 }
 
 /**
   * gnutls_srp_server_get_username - This function returns the username of the peer
-  * @state: is a gnutls state
+  * @session: is a gnutls session
   *
   * This function will return the username of the peer. This should only be
   * called in case of SRP authentication and in case of a server.
   * Returns NULL in case of an error.
   *
   **/
-const char *gnutls_srp_server_get_username(GNUTLS_STATE state)
+const char *gnutls_srp_server_get_username(gnutls_session session)
 {
 	SRP_SERVER_AUTH_INFO info;
 
 	CHECK_AUTH(GNUTLS_CRD_SRP, NULL);
 
-	info = _gnutls_get_auth_info(state);
+	info = _gnutls_get_auth_info(session);
 	if (info == NULL)
 		return NULL;
 	return info->username;
 }
 
+/* FIXME: Functions for backwards compatibility 
+ */
+
+void gnutls_srp_free_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS sc) {
+	return gnutls_srp_free_client_credentials( sc);
+}
+
+void gnutls_srp_free_server_cred( GNUTLS_SRP_SERVER_CREDENTIALS sc) {
+	return gnutls_srp_free_server_credentials( sc);
+}
+
+int gnutls_srp_allocate_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS *sc) {
+	return gnutls_srp_allocate_client_credentials( sc);
+}
+
+int gnutls_srp_allocate_server_cred( GNUTLS_SRP_SERVER_CREDENTIALS *sc) 
+{
+	return gnutls_srp_allocate_server_credentials( sc);
+}
+
+int gnutls_srp_set_server_cred_file( GNUTLS_SRP_SERVER_CREDENTIALS res, char *password_file, char * password_conf_file) 
+{
+	return gnutls_srp_set_server_credentials_file( res, password_file, password_conf_file);
+}
+
+int gnutls_srp_set_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS res, char *username, char * password) 
+{
+	return gnutls_srp_set_client_credentials( res, username, password);
+}
+
 #endif /* ENABLE_SRP */
