@@ -66,7 +66,7 @@ int more_info = 0;
 int tls1_ok = 0;
 int ssl3_ok = 0;
 
-typedef int (*TEST_FUNC)( GNUTLS_STATE);
+typedef int (*TEST_FUNC)( gnutls_session);
 
 typedef struct {
 	char* test_name;
@@ -124,7 +124,7 @@ int main(int argc, char **argv)
 	int err, ret;
 	int sd, i;
 	struct sockaddr_in sa;
-	GNUTLS_STATE state;
+	gnutls_session state;
 	char buffer[MAX_BUF + 1];
 	struct hostent *server_host;
 	int ssl3_ok = 0;
